@@ -65,30 +65,6 @@ if __name__ == '__main__':
     parser_a.add_argument("-d", "--work_dir",
                           help="path of output_dir, defaults as maker_dir", default="maker_dir", type=str)
 
-    # argparse for Protein2Genome
-    parser_a = subparsers.add_parser('Protein2Genome',
-                                     help='get gene structure from homo protein',
-                                     description='get gene structure from homo protein')
-
-    parser_a.add_argument('genome_file', type=str,
-                          help='Path of target geonome fasta file')
-    parser_a.add_argument('protein_fasta', type=str,
-                          help='Path of query protein fasta file')
-    parser_a.add_argument("-o", "--output_prefix", help="Output prefix name (default as Protein2Genome)",
-                          default="Protein2Genome.gff3", type=str)
-    parser_a.add_argument("-l", "--log_file",
-                          help="path for log file (default as None)", type=str)
-    parser_a.add_argument("-t", "--tmp_path", help="path for tmp dir (default in dir which have genome file)",
-                          default=None, type=str)
-    parser_a.add_argument(
-        "-n", "--num_threads", help="cpu number (default as 10)", default=10, type=int)
-    parser_a.add_argument("-c", "--gene_coverage", help="lowest gene coverage for genblasta hit use (default as 0.5)",
-                          default=0.5, type=float)
-    parser_a.add_argument("-a", "--genblasta_hit_num", help="geneblasta hit number (default as 20)", default=20,
-                          type=int)
-    parser_a.add_argument("-f", "--flank_range", help="flank range for genewise (default as 1000)", default=1000,
-                          type=int)
-
     # argparse for GeneStruComp
     parser_a = subparsers.add_parser('GeneStruComp',
                                      help='Compare two different genetic structure annotations',
@@ -279,8 +255,8 @@ if __name__ == '__main__':
 
     # MakerPlantRepeat
     if args_dict["subcommand_name"] == "MakerPlantRepeat":
-        from api.xuyuxing.genome.maker_p import maker_p_repeat_main
-        from lib.common.util import configure_parser
+        from toolbiox.api.xuyuxing.genome.maker_p import maker_p_repeat_main
+        from toolbiox.lib.common.util import configure_parser
 
         # configure file argument parse
 
@@ -370,7 +346,7 @@ if __name__ == '__main__':
         args.output_gff = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/base_on_yuan/blat.output.gff"
         """
 
-        from src.xuyuxing.GenomeTools.Gene2Genome import cDNA2Genome_main
+        from toolbiox.src.xuyuxing.GenomeTools.Gene2Genome import cDNA2Genome_main
         cDNA2Genome_main(args)
 
     # MergeMaker
@@ -390,9 +366,9 @@ if __name__ == '__main__':
         """
 
         import re
-        from lib.common.genome.seq_base import read_fasta_by_faidx
-        from lib.common.genome.genome_feature2 import read_gff_file, ChrLoci, GenomeFeature, cluster_of_chr_loci, write_gff_file
-        from lib.xuyuxing.base.base_function import multiprocess_running, mkdir
+        from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+        from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, ChrLoci, GenomeFeature, cluster_of_chr_loci, write_gff_file
+        from toolbiox.lib.xuyuxing.base.base_function import multiprocess_running, mkdir
 
         def fancy_name_parse(input_string):
             match_obj = re.match(r'^(\S+)_(\d+)-(\d+)$', input_string)
@@ -648,8 +624,8 @@ if __name__ == '__main__':
         args.evm_gff3_output = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/pasa/protein/genewise.evm.gff3"
         """
 
-        from lib.common.genome.genome_feature2 import read_gff_file
-        from lib.common.util import printer_list
+        from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
+        from toolbiox.lib.common.util import printer_list
 
         gf_dict = read_gff_file(args.genewise_gff3)
 
@@ -687,9 +663,9 @@ if __name__ == '__main__':
         args.hard_mask = False
         """
 
-        from lib.common.genome.genome_feature2 import read_gff_file
-        from lib.common.genome.seq_base import read_fasta_by_faidx, BioSeq
-        from lib.xuyuxing.math.set_operating import merge_intervals, interval_minus_set
+        from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
+        from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx, BioSeq
+        from toolbiox.lib.xuyuxing.math.set_operating import merge_intervals, interval_minus_set
 
         def get_seq(seq, get_range, mask):
             if mask == 'hard':
@@ -792,10 +768,10 @@ if __name__ == '__main__':
     elif args_dict["subcommand_name"] == "AnnotationMerge":
 
         import sys
-        from api.xuyuxing.file_parser.interproscan_results import interproscan_results_parser
-        from api.common.genome.blast import NR_blast_annotation_extractor
-        from lib.common.fileIO import tsv_file_dict_parse
-        from lib.common.util import printer_list
+        from toolbiox.api.xuyuxing.file_parser.interproscan_results import interproscan_results_parser
+        from toolbiox.api.common.genome.blast import NR_blast_annotation_extractor
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.lib.common.util import printer_list
 
         """
         class abc():
@@ -851,18 +827,18 @@ if __name__ == '__main__':
 
     # PseudoGene
     elif args_dict["subcommand_name"] == "PseudoGene":
-        from src.xuyuxing.GenomeTools.PseudoGene import pseudogene_main
+        from toolbiox.src.xuyuxing.GenomeTools.PseudoGene import pseudogene_main
         pseudogene_main(args)
 
     # AnnoCleaner
     elif args_dict["subcommand_name"] == "AnnoCleaner":
-        from src.xuyuxing.GenomeTools.AnnoCleaner import AnnoCleaner_main
+        from toolbiox.src.xuyuxing.GenomeTools.AnnoCleaner import AnnoCleaner_main
         AnnoCleaner_main(args)
 
     # EasyMaker
     elif args_dict["subcommand_name"] == "EasyMaker":
-        from lib.common.util import configure_parser
-        from api.xuyuxing.genome.maker import maker_main
+        from toolbiox.lib.common.util import configure_parser
+        from toolbiox.api.xuyuxing.genome.maker import maker_main
 
         # configure file argument parse
 
@@ -925,27 +901,22 @@ if __name__ == '__main__':
         # print(vars(args))
         maker_main(args)
 
-    # Protein2Genome
-    elif args_dict["subcommand_name"] == "Protein2Genome":
-        from src.xuyuxing.GenomeTools.Gene2Genome import Protein2Genome_main
-        Protein2Genome_main(args)
-
     # MaskFasta2Gff
     elif args_dict["subcommand_name"] == "MaskFasta2Gff":
-        from src.xuyuxing.GenomeTools.MaskFasta2gff import MaskFasta2Gff_main
+        from toolbiox.src.xuyuxing.GenomeTools.MaskFasta2gff import MaskFasta2Gff_main
         MaskFasta2Gff_main(args)
 
     # RepeatMasker2Gff3
     elif args_dict["subcommand_name"] == "RepeatMasker2Gff3":
-        from src.xuyuxing.GenomeTools.RepeatMasker2Gff3 import RepeatMasker2Gff3_main
+        from toolbiox.src.xuyuxing.GenomeTools.RepeatMasker2Gff3 import RepeatMasker2Gff3_main
         RepeatMasker2Gff3_main(args)
 
     # GeneBank2Gff3
     elif args_dict["subcommand_name"] == "GeneBank2Gff3":
-        from src.xuyuxing.GenomeTools.GeneBank2Gff3 import GeneBank2Gff3_main
+        from toolbiox.src.xuyuxing.GenomeTools.GeneBank2Gff3 import GeneBank2Gff3_main
         GeneBank2Gff3_main(args)
 
     # GeneBank2Gff3
     elif args_dict["subcommand_name"] == "ProteinByPfam":
-        from src.xuyuxing.GenomeTools.ProteinByPfam import ProteinByPfam_main
+        from toolbiox.src.xuyuxing.GenomeTools.ProteinByPfam import ProteinByPfam_main
         ProteinByPfam_main(args)
\ No newline at end of file
