@@ -1,19 +1,19 @@
-from lib.common.genome.genome_feature2 import Gene, read_gff_file
-from lib.common.genome.seq_base import read_fasta_by_faidx, write_fasta
-from lib.xuyuxing.base.common_command import merge_dict
-from lib.common.util import printer_list
-from lib.common.os import mkdir, cmd_run
-from lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.genome.genome_feature2 import Gene, read_gff_file
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx, write_fasta
+from toolbiox.lib.xuyuxing.base.common_command import merge_dict
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.os import mkdir, cmd_run
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 import re
-from api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
+from toolbiox.api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
 from interlap import InterLap
-from lib.common.math.set import merge_same_element_set
-from lib.common.math.interval import section, merge_intervals
+from toolbiox.lib.common.math.set import merge_same_element_set
+from toolbiox.lib.common.math.interval import section, merge_intervals
 from collections import OrderedDict
-from api.xuyuxing.comp_genome.orthofinder import tsv_to_gene_pair
+from toolbiox.api.xuyuxing.comp_genome.orthofinder import tsv_to_gene_pair
 import numpy as np
-from api.common.genome.blast import outfmt6_read_big
-from api.xuyuxing.plot.geneplot import add_box
+from toolbiox.api.common.genome.blast import outfmt6_read_big
+from toolbiox.api.xuyuxing.plot.geneplot import add_box
 import matplotlib.pyplot as plt
 
 # running mcscanx
@@ -877,7 +877,7 @@ if __name__ == "__main__":
                     species2_prefix='bb', species2_aa_fasta=None, skip_gene_list=[], give_bls_file=None)
 
     # parse
-    # from lib.evolution.mcscan import WGD_check_pipeline
+    # from toolbiox.lib.evolution.mcscan import WGD_check_pipeline
     from collections import Counter, OrderedDict
 
     query_species = 'Ash'
