@@ -1,8 +1,8 @@
 import os
 import re
 import shutil
-from config import treeshrink_path
-from lib.common.os import cmd_run
+from toolbiox.config import treeshrink_path
+from toolbiox.lib.common.os import cmd_run
 
 
 def treeshrink_running(tree_file, outdir, q_value=0.05, keep=False):
