@@ -4,6 +4,7 @@ import gzip
 import pandas as pd
 import numpy as np
 from collections import OrderedDict
+import hashlib
 
 csv.field_size_limit(100000000)
 
@@ -287,3 +288,12 @@ def write_matrix_file(matrix, col_list, row_list, output_file):
             g_id = row_list[i]
             f.write(g_id + "\t" + "\t".join([str(j)
                                              for j in matrix[i]]) + "\n")
+
+
+def get_file_md5(file_path):
+    md5_hash = hashlib.md5()
+    with open(file_path, "rb") as f:
+        # Read and update hash in chunks of 4K
+        for byte_block in iter(lambda: f.read(4096), b""):
+            md5_hash.update(byte_block)
+    return md5_hash.hexdigest()
