@@ -5,10 +5,10 @@ import matplotlib.ticker as ticker
 import matplotlib.patheffects as path_effects
 from matplotlib.collections import PatchCollection
 import re
-from lib.common.genome.genome_feature2 import read_gff_file, convert_dict_structure
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.fileIO import read_list_file, tsv_file_dict_parse
-from api.xuyuxing.plot.base import add_stick_box_plot, add_small_axes_on_other
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, convert_dict_structure
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.lib.common.fileIO import read_list_file, tsv_file_dict_parse
+from toolbiox.api.xuyuxing.plot.base import add_stick_box_plot, add_small_axes_on_other
 from collections import OrderedDict
 
 
@@ -620,7 +620,7 @@ if __name__ == "__main__":
     plt.show()
 
     # plot WGD synteny genome cover
-    from api.xuyuxing.comp_genome.mcscan import WGD_check_pipeline
+    from toolbiox.api.xuyuxing.comp_genome.mcscan import WGD_check_pipeline
 
     query_species = 'Ash'
     query_gff3 = '/lustre/home/xuyuxing/Work/Gel/synteny/redo_big/Ash.gff3'
@@ -645,7 +645,7 @@ if __name__ == "__main__":
                       s_range_base_cover_chr_dict)
 
     # plot dotplot
-    from api.xuyuxing.comp_genome.mcscan import WGD_check_pipeline
+    from toolbiox.api.xuyuxing.comp_genome.mcscan import WGD_check_pipeline
 
     query_species = 'Ash'
     query_gff3 = '/lustre/home/xuyuxing/Work/Gel/synteny/redo_big/Ash.gff3'
