@@ -1,23 +1,14 @@
 import os
 import re
-import random
 import pickle
 from BCBio import GFF
-from pyfaidx import Fasta
 from interlap import InterLap
-from Bio.Seq import Seq, translate
-from Bio.SeqRecord import SeqRecord
-from Bio.SeqFeature import SeqFeature, FeatureLocation
-from lib.common.util import logging_init
-from lib.common.os import mkdir, cmd_run, multiprocess_running
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.genome.genome_feature2 import cds_judgment, ChrLoci, GenomeFeature, write_gff_file, cluster_of_chr_loci
-from lib.xuyuxing.seq.genome_feature import GenomeFeature as old_GenomeFeature
-from lib.common.math.interval import section, merge_intervals, interval_minus_set
-# from lib.xuyuxing.seq.genome_feature import ChrLoci, GenomeFeature, cluster_of_chr_loci, write_GenomeFeature_to_GFF
-from api.xuyuxing.genome.genblasta import genblasta_run, genblasta_to_genewise, get_HPR_from_genewise_results, gene_to_aa, \
-    gene_to_cds, query_gene_to_speci
-from api.common.genome.blast import blastn_pair_running
+from Bio.SeqFeature import SeqFeature
+from toolbiox.lib.common.os import mkdir, multiprocess_running
+from toolbiox.lib.common.genome.genome_feature2 import cds_judgment, ChrLoci, write_gff_file, cluster_of_chr_loci
+from toolbiox.lib.xuyuxing.seq.genome_feature import GenomeFeature as old_GenomeFeature
+from toolbiox.lib.common.math.interval import merge_intervals
+from toolbiox.api.common.genome.blast import blastn_pair_running
 
 
 def cDNA_coord_shift(give_site, direction, sub_feature_list):
@@ -706,159 +697,8 @@ def cDNA2Genome_main(args):
     #                   blat_hit_rank, blat_hit_note, blat_cds_good, blat_used)
 
 
-def Protein2Genome_main(args):
-
-    # prepare args
-
-    if not args.tmp_path:
-        args.tmp_path = os.path.dirname(
-            os.path.abspath(args.genome_file)) + "/tmp"
-
-    mkdir(args.tmp_path, True)
-
-    logger = logging_init("HomoAnno", args.log_file)
-
-    args_info_string = "Argument list:\n"
-    attrs = vars(args)
-
-    for item in attrs.items():
-        args_info_string = args_info_string + ("%s: %s\n" % item)
-
-    logger.info(args_info_string)
-
-    # get query sequence
-    logger.info("Step1: split query sequence to many small files")
-
-    query_gene_dict = read_fasta_by_faidx(args.protein_fasta)
-
-    ready_seq_num = 0
-    query_file_list = []
-    for file_name in os.listdir(args.tmp_path):
-        matchobj = re.match('^query_(.*)fa$', file_name)
-        if matchobj:
-            query_file_name = args.tmp_path + "/" + file_name
-            ready_seq_num = ready_seq_num + \
-                len(read_fasta_by_faidx(query_file_name))
-            query_file_list.append(query_file_name)
-
-    if not len(query_gene_dict) == ready_seq_num:
-        logger.info("make new query fasta files")
-        file_num = 0
-        query_file_list = []
-        query_file_name = "%s/query_%d.fa" % (args.tmp_path, file_num)
-        query_file_list.append(query_file_name)
-        f = open(query_file_name, 'w')
-
-        seq_in_this_file_num = 0
-        writed_seq_num = 0
-        for gene_id in query_gene_dict:
-            gene = query_gene_dict[gene_id]
-            f.write(">%s\n%s\n" % (gene_id, gene.seq))
-            writed_seq_num += 1
-            seq_in_this_file_num += 1
-            if seq_in_this_file_num == 2 and seq_in_this_file_num != len(query_gene_dict):
-                f.close()
-                file_num = file_num + 1
-                query_file_name = "%s/query_%d.fa" % (
-                    args.tmp_path, file_num)
-                query_file_list.append(query_file_name)
-                f = open(query_file_name, 'w')
-                seq_in_this_file_num = 0
-        f.close()
-    else:
-        logger.info("ready have query fasta files")
-
-    # genblasta and genewise
-    logger.info(
-        "Step2: running genblasta and genewise to annotate genome again")
-
-    # genblasta
-    genblasta_finished_flag = True
-    unfinished_query_list = []
-    for q_file in query_file_list:
-        if not os.path.exists(q_file + ".gba"):
-            unfinished_query_list.append(q_file)
-            genblasta_finished_flag = False
-
-    if not genblasta_finished_flag:
-        logger.info("genblasta: %d jobs in %d pool" %
-                    (len(unfinished_query_list), args.num_threads))
-
-        args_list = [(i, args.genome_file, i + ".gba", args.gene_coverage, args.genblasta_hit_num) for i in
-                     unfinished_query_list]
-        genblasta_out = multiprocess_running(
-            genblasta_run, args_list, args.num_threads, log_file=args.log_file)
-
-        logger.info("genblasta is finished")
-    else:
-        logger.info("genblasta is already finished")
-
-    genewise_finished_flag = True
-    unfinished_query_list = []
-    for q_file in query_file_list:
-        if not os.path.exists(q_file + ".wise.pep"):
-            unfinished_query_list.append(q_file)
-            genewise_finished_flag = False
-
-    if not genewise_finished_flag:
-        logger.info("genewise: %d jobs in %d pool" %
-                    (len(unfinished_query_list), args.num_threads))
-        mkdir(args.tmp_path + "/genewise_run/", False)
-        args_list = [
-            (
-                i, args.genome_file, i + ".gba", args.tmp_path +
-                "/genewise_run/", args.flank_range,
-                i + ".wise",
-                False)
-            for
-            i in
-            unfinished_query_list]
-        genewise_running_out = multiprocess_running(genblasta_to_genewise, args_list, args.num_threads,
-                                                    log_file=args.log_file)
-
-        genewise_error_query_file_list = []
-        for i in genewise_running_out:
-            if genewise_running_out[i]['output'] == "error":
-                genewise_error_query_file_list.append(
-                    genewise_running_out[i]['args'][0])
-
-        logger.info("error file name:\n")
-
-        for i in genewise_error_query_file_list:
-            logger.info(i + "\n")
-
-        logger.info("\n")
-
-        logger.info("genewise is finished, %d seq get genewise error" %
-                    len(genewise_error_query_file_list))
-
-    else:
-        logger.info("genewise is already finished")
-
-    logger.info("genblasta and genewise OK")
-
-
 if __name__ == '__main__':
 
-    # Protein2Genome
-
-    class abc():
-        pass
-
-    args = abc()
-
-    args.genome_file = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/base_on_yuan/Gel.genome.v1.0.fasta"
-    args.protein_fasta = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/base_on_yuan/GWHAAEX00000000.Protein.faa"
-    args.output_prefix = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/base_on_yuan/HomoAnno"
-    args.log_file = "/lustre/home/xuyuxing/Database/Gel/genome/annotation/base_on_yuan/log"
-    args.tmp_path = None
-    args.num_threads = 10
-    args.gene_coverage = 0.5
-    args.genblasta_hit_num = 20
-    args.flank_range = 1000
-
-    Protein2Genome_main(args)
-
     # cDNA2Genome
     """
     blat Gel.genome.v1.0.fasta /dev/null /dev/null -tileSize=11 -makeOoc=11.ooc -repMatch=1024
