@@ -1,11 +1,11 @@
 import os
 import re
 from copy import deepcopy
-from lib.common.genome.genome_feature2 import ChrLoci, GenomeFeature, read_gff_file, cds_judgment, cluster_of_chr_loci, write_gff_file
-from lib.common.genome.seq_base import read_fasta
-from lib.common.os import mkdir, multiprocess_running
-from api.common.genome.blast import blastn_pair_running
-from lib.common.math.interval import merge_intervals
+from toolbiox.lib.common.genome.genome_feature2 import ChrLoci, GenomeFeature, read_gff_file, cds_judgment, cluster_of_chr_loci, write_gff_file
+from toolbiox.lib.common.genome.seq_base import read_fasta
+from toolbiox.lib.common.os import mkdir, multiprocess_running
+from toolbiox.api.common.genome.blast import blastn_pair_running
+from toolbiox.lib.common.math.interval import merge_intervals
 from interlap import InterLap
 import pickle
 
