@@ -1,13 +1,13 @@
-from lib.common.util import printer_list
-from api.xuyuxing.resource.GO import Obo
-from lib.common.os import multiprocess_running
-from api.xuyuxing.file_parser.fileIO import tsv_file_parse, tsv_file_dict_parse
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from api.xuyuxing.resource.uniprot import iterUniprotDB, extract_swiss_info
+from toolbiox.lib.common.util import printer_list
+from toolbiox.api.xuyuxing.resource.GO import Obo
+from toolbiox.lib.common.os import multiprocess_running
+from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse, tsv_file_dict_parse
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.api.xuyuxing.resource.uniprot import iterUniprotDB, extract_swiss_info
 import pickle
 import os
 import re
-from lib.common.genome.genome_feature2 import read_gff_file
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
 
 
 def Arabidopsis_genome_function(work_dir, clean_data_fasta, clean_to_raw_id_map, araport_gff, uniprot_sprot_plants_db, uniprot_trembl_plants_db, kegg_overview, plantcyc_file, obo_file):
